@@ -76,14 +76,15 @@ void DialogSelectMaster::createWidgets(Mixer *ptr_mixer)
 
         for( int i =0; i<Mixer::mixers().count(); i++ )
         {
-            Mixer *mixer = (Mixer::mixers())[i];
-            m_cMixer->addItem( mixer->readableName(), mixer->id() );
+            const Mixer *mixer = (Mixer::mixers())[i];
+            const shared_ptr<MixDevice> md = mixer->getLocalMasterMD();
+            const QString iconName = (md!=nullptr) ? md->iconName() : "media-playback-start";
+            m_cMixer->addItem(QIcon::fromTheme(iconName), mixer->readableName(), mixer->id() );
          } // end for all_Mixers
         // Make the current Mixer the current item in the ComboBox
         int findIndex = m_cMixer->findData( ptr_mixer->id() );
         if ( findIndex != -1 ) m_cMixer->setCurrentIndex( findIndex );
         
-    
         m_cMixer->setToolTip( i18n("Current mixer" ) );
         mixerNameLayout->addWidget(m_cMixer, 1);
         layout->addSpacing(DialogBase::verticalSpacing());
@@ -196,6 +197,8 @@ void DialogSelectMaster::createPage(Mixer* mixer)
             }
         }
     }
+
+    setButtonEnabled(QDialogButtonBox::Ok, m_channelSelector->count()>0);
 }
 
 
@@ -222,7 +225,7 @@ void DialogSelectMaster::apply()
     	QString control_id = item->data(Qt::UserRole).toString();
 		mixer->setLocalMasterMD( control_id );
 		Mixer::setGlobalMaster(mixer->id(), control_id, true);
-		ControlManager::instance().announce(mixer->id(), ControlChangeType::MasterChanged, QString("Select Master Dialog"));
+		ControlManager::instance().announce(mixer->id(), ControlManager::MasterChanged, QString("Select Master Dialog"));
    }
 }
 
